# -*- coding: utf-8 -*-
"""
Created on Feb 26 2017 17:53

@author: Jan.Reimes
"""

import pandas
import numpy as np

def createTestData(**kwargs):

    # some constants
    minMOS=kwargs.get('minMOS', 1.05)
    maxMOS=kwargs.get('maxMOS', 4.95)
    seed = kwargs.get('seed', None)
    mosRange = maxMOS - minMOS
    mosTitle = kwargs.get('mosTitle', 'X-MOS')
    generateObjCI95 = kwargs.get('generateObjCI95', False)

    ### Generate subjective Data ###
    np.random.seed(seed)
    N = kwargs.get('N', 60) # number of files/conditions
    avgCI95 = kwargs.get('avgCI95', 0.10) # average CI95
    varCI95 = kwargs.get('varCI95', 0.025)  # variance of CI95
    #polynom = kwargs.get('polynom', [-0.005, 0.005, 1, 0])
    polynom = kwargs.get('polynom', [ 0.03964898, -0.26313382,  1.30656766, -0.09944892])

    MOS_Subj = pandas.Series(data=np.clip(mosRange*np.random.rand(N) + minMOS, a_min=1.0, a_max=5.0), name=mosTitle)
    CI95_Subj = pandas.Series(data=np.maximum(varCI95*np.random.randn(N) + avgCI95, 0), name='CI95(%s)' % mosTitle)
    CI95_Obj = pandas.Series(data=np.maximum(varCI95*np.random.randn(N) + avgCI95, 0), name='CI95_Obj(%s)' % mosTitle)

    ### Generate dummy model output ###
    avgRMSE = 0.2
    predictionError = avgRMSE*np.random.randn(N)
    MOS_Obj = np.poly1d(polynom)(MOS_Subj) # shift by artifical mapping function
    MOS_Obj = np.clip(MOS_Obj + predictionError, a_min=1.0, a_max=5.0) # add "noise"
    MOS_Obj = pandas.Series(data=MOS_Obj, name="%s_instrumental" % mosTitle) # convert to Series
    I = np.argmax(np.abs(MOS_Subj - MOS_Obj))  # find abs max delta
    #MOS_Obj[I] = MOS_Subj[I] + 0*(MOS_Obj[I] - MOS_Subj[I]) # emphasize outlier

    if generateObjCI95:
        return MOS_Subj, CI95_Subj, MOS_Obj, N, CI95_Obj
    else:
        return MOS_Subj, CI95_Subj, MOS_Obj, N

if __name__ == "__main__":
    pass