# -*- coding: utf-8 -*-
"""
Created on Mar 08 2017 00:08

@author: Jan.Reimes
"""

import os.path as p, sys
thisPath = p.split(p.realpath(__file__))[0]
sys.path.append(thisPath)

import numpy as np

import matplotlib.pyplot as plt
from common.math.GenerateTestData import createTestData
from common.plot.PlotTools import PlotCorr
from common.math.polyFitConstrained import polyfit_constr

if __name__ == "__main__":

    ## test data
    MOS_Subj, CI95, MOS_Obj, nbrData, CI95_Obj = createTestData(seed=28041980, generateObjCI95=True)
    xmin, xmax = 1, 5
    d = 3

    # fit
    pol = np.poly1d(np.polyfit(MOS_Obj,MOS_Subj,d))
    for w in [0.0, 0.15, 0.5, 1]:
        pol_c = polyfit_constr(MOS_Obj, MOS_Subj, d, weight_mean=w, fixed_points=[(5,5)], fixed_points_distance=[0.33])
        print(pol_c)
        err = MOS_Subj - pol_c(MOS_Obj)
        idx = np.argmax(np.abs(err))

        print("Check fixed point: x=5.0 => y=%f" % pol_c(5.0))
        print("Check max error: e=%.3f, x=%.2f => y=%.2f" % (err[idx], pol_c(MOS_Obj[idx]), MOS_Subj[idx]))
        # plot

        for mapped in [False, True]:
            title = 'Avg. Weight = %.2f - Mapped=%s' % (w, mapped)
            title = None
            axLabels = [r'$\mathrm{MOS-LQO}_{fb}$', r'$\mathrm{MOS-LQS}_{fb}$']
            if mapped:
                axLabels[0] = r'$\mathrm{MOS-LQO}_{fb}$ [mapped]'

            fig, ax = PlotCorr(MOS_Obj, MOS_Subj, legendText=MOS_Subj.name, title=title, xErr=CI95_Obj, yErr=CI95, ConstrainedMapping=True, ConstrainedMappingMeanWeight=w, ShowMappedValues=mapped, fontsize=12, axLabels=axLabels)
    plt.show()
